smf_firebase_analytics library

The module that records what users do in the app, and the screens they see, with Firebase Analytics: FirebaseAnalyticsModule, a provider of the analytics role of the SMF module model.

Classes

FirebaseAnalyticsModule
The module that records what users do in the app with Firebase Analytics and the firebase_analytics package, and so provides the analytics role.